package com.ruoyi.rocketmq.service.impl;

import java.util.List;
import com.ruoyi.common.core.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.rocketmq.mapper.RmFileInfoMapper;
import com.ruoyi.rocketmq.domain.RmFileInfo;
import com.ruoyi.rocketmq.service.IRmFileInfoService;

/**
 * 文件信息Service业务层处理
 * 
 * @author gyt
 * @date 2025-09-15
 */
@Service
public class RmFileInfoServiceImpl implements IRmFileInfoService 
{
    @Autowired
    private RmFileInfoMapper rmFileInfoMapper;

    /**
     * 查询文件信息
     * 
     * @param id 文件信息主键
     * @return 文件信息
     */
    @Override
    public RmFileInfo selectRmFileInfoById(Long id)
    {
        return rmFileInfoMapper.selectRmFileInfoById(id);
    }

    /**
     * 查询文件信息列表
     * 
     * @param rmFileInfo 文件信息
     * @return 文件信息
     */
    @Override
    public List<RmFileInfo> selectRmFileInfoList(RmFileInfo rmFileInfo)
    {
        return rmFileInfoMapper.selectRmFileInfoList(rmFileInfo);
    }

    /**
     * 新增文件信息
     * 
     * @param rmFileInfo 文件信息
     * @return 结果
     */
    @Override
    public int insertRmFileInfo(RmFileInfo rmFileInfo)
    {
        rmFileInfo.setCreateTime(DateUtils.getNowDate());
        return rmFileInfoMapper.insertRmFileInfo(rmFileInfo);
    }

    /**
     * 修改文件信息
     * 
     * @param rmFileInfo 文件信息
     * @return 结果
     */
    @Override
    public int updateRmFileInfo(RmFileInfo rmFileInfo)
    {
        rmFileInfo.setUpdateTime(DateUtils.getNowDate());
        return rmFileInfoMapper.updateRmFileInfo(rmFileInfo);
    }

    /**
     * 批量删除文件信息
     * 
     * @param ids 需要删除的文件信息主键
     * @return 结果
     */
    @Override
    public int deleteRmFileInfoByIds(Long[] ids)
    {
        return rmFileInfoMapper.deleteRmFileInfoByIds(ids);
    }

    /**
     * 删除文件信息信息
     * 
     * @param id 文件信息主键
     * @return 结果
     */
    @Override
    public int deleteRmFileInfoById(Long id)
    {
        return rmFileInfoMapper.deleteRmFileInfoById(id);
    }
}
